Pure Elixir model specification used to build IREE-backed tokenizers.
These structs are not tokenizers by themselves. They are small declarative
descriptions that can be passed to IREE.Tokenizers.Tokenizer.init/1.
Currently supported model constructors live in:
Summary
Types
A model specification that can be turned into an IREE tokenizer with
IREE.Tokenizers.Tokenizer.init/1.
Functions
Returns metadata about the model specification.
Types
A model specification that can be turned into an IREE tokenizer with
IREE.Tokenizers.Tokenizer.init/1.